import {
  select,
  json,
  tree,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;

const margin = { top: 0, right: 50, bottom: 0, left: 75};
// Calculating the height and width of a tree
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree().size([innerHeight, innerWidth]);

const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');

// Use a group element to position the tree layout
const g = zoomG.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
// To have zoom effects 
svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));
// Parsing the data 
json('data.json')
  .then(data => {
    const root = hierarchy(data);
    const links = treeLayout(root).links();
    const linkPathGenerator = linkHorizontal()
      .x(d => d.y)
      .y(d => d.x);
 // To define the link to the nodes 
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', linkPathGenerator);
 // To add the node labels 
    g.selectAll('text').data(root.descendants())
      .enter().append('text')
        .attr('x', d => d.y)
        .attr('y', d => d.x)
        .attr('dy', '0.30em')
        .attr('text-anchor', d => d.children ? 'middle' : 'start') // To center the node label 
        .attr('font-size', d => 3.5 - d.depth + 'em') // A value for depth is assigned to every node when passed to hierarchy.
        .text(d => d.data.data.id)
  			.attr('fill', d => d.data.data.color);
  });